@@ -13,20 +13,22 @@ import click
 from jaws_libp.clients import CategoryConsumer, ClassProducer
 from jaws_libp.entities import AlarmClass, AlarmPriority
 
+CATEGORIES = []
 
 if __name__ == "__main__":
     cat_consumer = CategoryConsumer('set_class.py')
-    categories = cat_consumer.get_keys_then_done()
+    CATEGORIES = cat_consumer.get_keys_then_done()
 
 
+# pylint: disable=duplicate-code,missing-function-docstring,no-value-for-parameter,too-many-arguments
 @click.command()
 @click.option('--file', is_flag=True,
               help="Imports a file of key=value pairs (one per line) where the key is alarm name and value is JSON "
                    "encoded AVRO formatted per the alarm-classes-value schema")
 @click.option('--unset', is_flag=True, help="Remove the class")
-@click.option('--category', type=click.Choice(categories),
+@click.option('--category', type=click.Choice(CATEGORIES),
               help="The alarm category (Options queried on-demand from alarm-categories topic)")
-@click.option('--priority', type=click.Choice(AlarmPriority._member_names_), help="The alarm priority")
+@click.option('--priority', type=click.Choice(list(map(lambda c: c.name, AlarmPriority))), help="The alarm priority")
 @click.option('--filterable/--not-filterable', is_flag=True, default=True,
               help="True if alarm can be filtered out of view")
 @click.option('--latching/--not-latching', is_flag=True, default=True,
@@ -38,8 +40,8 @@ if __name__ == "__main__":
 @click.option('--offdelayseconds', type=int, default=None, help="Number of off delay seconds")
 @click.argument('name')
 def set_class(file, unset, category,
-        priority, filterable, latching, pointofcontactusername, rationale,
-        correctiveaction, ondelayseconds, offdelayseconds, name) -> None:
+              priority, filterable, latching, pointofcontactusername, rationale,
+              correctiveaction, ondelayseconds, offdelayseconds, name) -> None:
     producer = ClassProducer('set_class.py')
 
     key = name
@@ -84,4 +86,3 @@ def click_main() -> None:
 
 if __name__ == "__main__":
     click_main()
-
